==> haskell-typst-symbols-0.1.4-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-typst-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typst-symbols
version:              0.1.4
visibility:           public
id:                   typst-symbols-0.1.4-HjOBFCqxenh64KEW8EzY50
key:                  typst-symbols-0.1.4-HjOBFCqxenh64KEW8EzY50
license:              MIT
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/typst-symbols
synopsis:             Symbol and emoji lookup for typst language
description:
    This package defines symbol and emoji codes for the
    typst language (<https://typst.app>).

category:             Text
abi:                  fad9a484d5d35c224c6d3541b9ca3e73
exposed:              True
exposed-modules:      Typst.Emoji Typst.Shorthands Typst.Symbols
import-dirs:          /usr/lib/ghc-9.2.8/site-local/typst-symbols-0.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/typst-symbols-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst-symbols
hs-libraries:         HStypst-symbols-0.1.4-HjOBFCqxenh64KEW8EzY50
depends:              base-4.16.4.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-typst-symbols/html/typst-symbols.haddock

haddock-html:         /usr/share/doc/haskell-typst-symbols/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typst-symbols-0.1.5-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-typst-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typst-symbols
version:              0.1.5
visibility:           public
id:                   typst-symbols-0.1.5-88gdpZCk9hecvC3Xgy0SF
key:                  typst-symbols-0.1.5-88gdpZCk9hecvC3Xgy0SF
license:              MIT
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/typst-symbols
synopsis:             Symbol and emoji lookup for typst language
description:
    This package defines symbol and emoji codes for the
    typst language (<https://typst.app>).

category:             Text
abi:                  8d8d381ca331099cad4532f51ef6c199
exposed:              True
exposed-modules:      Typst.Emoji Typst.Shorthands Typst.Symbols
import-dirs:          /usr/lib/ghc-9.2.8/site-local/typst-symbols-0.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/typst-symbols-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst-symbols
hs-libraries:         HStypst-symbols-0.1.5-88gdpZCk9hecvC3Xgy0SF
depends:              base-4.16.4.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-typst-symbols/html/typst-symbols.haddock

haddock-html:         /usr/share/doc/haskell-typst-symbols/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
